Finds dupliucated questions in a set of Question Banks
Usage
DUPbank(Qbank)
Arguments
Qbank
a list of Question Banks
Value
A
vector of duplicated questions
F
vector of duplicated files where the questions were extracted
I
vector of duplicated indexes where the questions were extracted
N
vector of duplicated indexes where the questions were extracted
Details
The program only checks the questions, not the answers.
One could thus have several questions with the same
wording, but different answers. I might change this in the future.
Given the list of duplicated questions one should edit the
original question bank files to remove them.
data(QBANK1)
### force some questions to be duplicates:QBANK1[[51]]=QBANK1[[25]]
QBANK1[[52]]=QBANK1[[12]]
QBANK1[[14]]=QBANK1[[4]]
DQ = DUPbank(QBANK1)
DQ