Learn R Programming

ProfessR (version 2.3)

IDandEM: Match ID and Email file

Description

Match ID and Email file

Usage

IDandEM(scrfn, sisroster, sel = 1:2, hnote = "Exam Results", SEND = TRUE)

Arguments

scrfn
list(ID=number, nam="name on scantron")
sisroster
list(ID=number, lastname='last name of student', fullname='full name of student')
sel
numeric, index= specify for a specific student
hnote
text, subject line on E-mail
SEND
logical, if FALSE, do not send

Value

Side Effects

Details

A set of files has been separated and stored. Each file is to sent to a different student with the exam results.

See Also

repair.id

Examples

Run this code

## Not run: 
# ##  read in the names of the files
# zfile = scan(file="ALLIDS", list(name="", ID=0, tfile=""), sep="," )
# ##  read in a roster.  The roster has
# ##   email addresses that are attached tot he files
# ##  by matching the ID in the zfile with the IDs in the data base
# load(file="/home/lees/Class/GEOL_105/Grades_2008/EXAM1/BB1.RDATA")
# 
# jroster = BB1
# 
# IDandEM(zfile, jroster, sel=1:10, hnote="GEOL105 EXAM3 Results", SEND=FALSE )
# IDandEM(zfile, jroster,  hnote="GEOL105 EXAM3 Results", SEND=FALSE )
# 
# ######## actual sending
# IDandEM(zfile, jroster, hnote="GEOL105 EXAM3 Results", SEND=TRUE )
# 
# 
# 
# ## End(Not run)




Run the code above in your browser using DataLab