Learn R Programming

ProfessR (version 2.3)

autoemail: AutoEmail

Description

Automatically email a file to an address using the perl program.

Usage

autoemail(eadd, sfile, hnote = "Exam Results")

Arguments

eadd
Email address
sfile
file to be sent
hnote
subject line

Value

Side Effects.

Details

This program will work well in Linux and Mac where Perl is installed - I am not sure about Windows. Creates a unix executable file, if perl is present.

See Also

IDandEM