Learn R Programming

ProfessR (version 2.3)

readSCANTRON: Read Scantron

Description

Read UNC scantron

Usage

readSCANTRON(fn = "t9543b.raw.csv", nq = 50, istart = 6)

Arguments

fn
character, name of digital file with raw scores
nq
integer, Number of questions to read
istart
integer, start of column for first question

Value

Nstudents
number of students
Nquestions
number of questions
Nams
names of students
ids
Ids of students
studans
matrix, student answers
key
key for grading

Details

The data is scanned by machine. If a student marks on the exam past the correct number of questions, the machine assumes there are legitimate repsonses beyond the key.

Examples

Run this code
## Not run: 
# 
# datadir =  "./DATA"
# rawfn1 = paste(datadir,'t6200a.raw.csv', sep="/")
# 
# B1 = readSCANTRON(rawfn1)
# ## End(Not run)


Run the code above in your browser using DataLab