Learn R Programming

ProfessR (version 2.3)

scramble.answers: Scramble Answers

Description

Randomly rearrange answers within a question of a test bank

Usage

scramble.answers(Qbank)

Arguments

Qbank
Question Bank (list of Questions)

Value

Question Bank List

Details

Takes the given list of questions, and returns same list with answers scrambled.

See Also

Get.testbank

Examples

Run this code

data(QBANK1)


QBANK1[[35]]

 NEWQB = scramble.answers(QBANK1) 
NEWQB[[35]]

Run the code above in your browser using DataLab